@@ -1,4 +1,4 @@
-## Copyright (C) 2010, 2012   Lukas F. Reichlin
+## Copyright (C) 2010-2014   Lukas F. Reichlin
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 
 function a = diag (a, b = 0)
 
-  if (nargin == 0 || nargin > 2)
+  if (nargin > 2)
     print_usage ();
   endif
 
