@@ -15,7 +15,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-Return true if argument is a real array.
+Return true if all arguments are real-valued arrays and false otherwise.
 
 Author: Lukas Reichlin <lukas.reichlin@gmail.com>
 Created: November 2011
@@ -28,7 +28,7 @@ Version: 0.3
 DEFUN_DLD (is_real_array, args, nargout,
    "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} is_real_array (@var{a}, @dots{})\n\
-Return true if argument is a real array.\n\
+Return true if all arguments are real-valued arrays and false otherwise.\n\
 @var{[]} is a valid array.\n\
 Avoid nasty stuff like @code{true = isreal (\"a\")}.\n\
 @end deftypefn")
